==> haskell-opentelemetry-0.8.0-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-opentelemetry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 opentelemetry
version:              0.8.0
visibility:           public
id:                   opentelemetry-0.8.0-LWScBb7uEad90Z56oHOeGn
key:                  opentelemetry-0.8.0-LWScBb7uEad90Z56oHOeGn
license:              Apache-2.0
maintainer:           ethercrow@gmail.com
author:               Dmitry Ivanov
description:          The OpenTelemetry Haskell Client https://opentelemetry.io
category:             OpenTelemetry
abi:                  97a6d4a44aab1a5b98364fa54ae6bfcd
exposed:              True
exposed-modules:
    OpenTelemetry.Eventlog OpenTelemetry.Eventlog_Internal
    OpenTelemetry.Metrics_Internal OpenTelemetry.Propagation
    OpenTelemetry.SpanContext

import-dirs:          /usr/lib/ghc-9.2.8/site-local/opentelemetry-0.8.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/opentelemetry-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-opentelemetry
hs-libraries:         HSopentelemetry-0.8.0-LWScBb7uEad90Z56oHOeGn
depends:
    base-4.16.4.0 bytestring-0.11.4.0 exceptions-0.10.4
    ghc-trace-events-0.1.2.8-AXrbrbo7fa5AubaYk3VnX7
    hashable-1.4.4.0-JPPoH0HitSIaCdulNsJk5

haddock-interfaces:
    /usr/share/doc/haskell-opentelemetry/html/opentelemetry.haddock

haddock-html:         /usr/share/doc/haskell-opentelemetry/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-opentelemetry-0.8.0-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-opentelemetry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 opentelemetry
version:              0.8.0
visibility:           public
id:                   opentelemetry-0.8.0-D4vdCxrwOrTCWx55JWb9Vj
key:                  opentelemetry-0.8.0-D4vdCxrwOrTCWx55JWb9Vj
license:              Apache-2.0
maintainer:           ethercrow@gmail.com
author:               Dmitry Ivanov
description:          The OpenTelemetry Haskell Client https://opentelemetry.io
category:             OpenTelemetry
abi:                  e5284896f5b2c99377ae5e97f83454bf
exposed:              True
exposed-modules:
    OpenTelemetry.Eventlog OpenTelemetry.Eventlog_Internal
    OpenTelemetry.Metrics_Internal OpenTelemetry.Propagation
    OpenTelemetry.SpanContext

import-dirs:          /usr/lib/ghc-9.2.8/site-local/opentelemetry-0.8.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/opentelemetry-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-opentelemetry
hs-libraries:         HSopentelemetry-0.8.0-D4vdCxrwOrTCWx55JWb9Vj
depends:
    base-4.16.4.0 bytestring-0.11.4.0 exceptions-0.10.4
    ghc-trace-events-0.1.2.9-FI8xtj0TQjuI48HJs0fG9x
    hashable-1.4.4.0-CxCIesSa4aLFiFeBLAsQal

haddock-interfaces:
    /usr/share/doc/haskell-opentelemetry/html/opentelemetry.haddock

haddock-html:         /usr/share/doc/haskell-opentelemetry/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
